# Changelog

## [0.1.0a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.1.0a2) (2024-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.1.0a1...0.1.0a2)

**Merged pull requests:**

- chore:semver\_versioning [\#230](https://github.com/OpenVoiceOS/OVOS-workshop/pull/230) ([JarbasAl](https://github.com/JarbasAl))

## [0.1.0a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.1.0a1) (2024-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.1.0...0.1.0a1)

**Merged pull requests:**

- chore:semver\_automations [\#228](https://github.com/OpenVoiceOS/OVOS-workshop/pull/228) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
